@@ -21,6 +21,7 @@ import glob
 import io
 import multiprocessing
 import os
+import pathlib
 import runpy
 import shutil
 import sys
@@ -34,7 +35,6 @@ from unittest import TestCase, mock
 import pyfakefs.tests.import_as_example
 import pyfakefs.tests.logsio
 from pyfakefs import fake_filesystem_unittest, fake_filesystem
-from pyfakefs.extra_packages import pathlib
 from pyfakefs.fake_filesystem import OSType
 from pyfakefs.fake_filesystem_unittest import (
     Patcher, Pause, patchfs, PatchMode
@@ -808,6 +808,12 @@ class TestOtherFS(fake_filesystem_unittest.TestCase):
         self.assertTrue(os.path.exists(path.upper()))
         self.assertTrue(os.path.ismount(r'\\share\foo'))
         self.assertTrue(os.path.ismount(r'C:'))
+        self.assertEqual('\\', os.sep)
+        self.assertEqual('\\', os.path.sep)
+        self.assertEqual('/', os.altsep)
+        self.assertEqual(';', os.pathsep)
+        self.assertEqual('\r\n', os.linesep)
+        self.assertEqual('nul', os.devnull)
 
     def test_linux(self):
         self.fs.os = OSType.LINUX
@@ -819,6 +825,12 @@ class TestOtherFS(fake_filesystem_unittest.TestCase):
         self.assertFalse(os.path.exists(path.upper()))
         self.assertTrue(os.path.ismount('/'))
         self.assertFalse(os.path.ismount('//share/foo'))
+        self.assertEqual('/', os.sep)
+        self.assertEqual('/', os.path.sep)
+        self.assertEqual(None, os.altsep)
+        self.assertEqual(':', os.pathsep)
+        self.assertEqual('\n', os.linesep)
+        self.assertEqual('/dev/null', os.devnull)
 
     def test_macos(self):
         self.fs.os = OSType.MACOS
@@ -830,6 +842,12 @@ class TestOtherFS(fake_filesystem_unittest.TestCase):
         self.assertTrue(os.path.exists(path.upper()))
         self.assertTrue(os.path.ismount('/'))
         self.assertFalse(os.path.ismount('//share/foo'))
+        self.assertEqual('/', os.sep)
+        self.assertEqual('/', os.path.sep)
+        self.assertEqual(None, os.altsep)
+        self.assertEqual(':', os.pathsep)
+        self.assertEqual('\n', os.linesep)
+        self.assertEqual('/dev/null', os.devnull)
 
     def test_drivelike_path(self):
         self.fs.os = OSType.LINUX
